pub struct PyAny(/* private fields */);Expand description
Represents any Python object.
Values of this type are accessed via PyO3’s smart pointers, e.g. as
Py<PyAny> or Bound<'py, PyAny>.
For APIs available on all Python objects, see the PyAnyMethods trait which is implemented for
Bound<'py, PyAny>.
See the guide for an explanation of the different Python object types.