pub struct PyKFold { /* private fields */ }Expand description
K-Fold cross-validator.
Splits data into n_splits consecutive (or shuffled) folds; each fold
is used once as the validation set while the remaining folds form the
training set.
Implementations
Sourceimpl PyKFold
impl PyKFold
Sourcepub fn new(
n_splits: usize,
shuffle: bool,
random_state: Option<u64>,
) -> PyResult<Self>
pub fn new( n_splits: usize, shuffle: bool, random_state: Option<u64>, ) -> PyResult<Self>
pub in addition to being reachable from Python via #[new], so
benches/core_helpers_benchmarks.rs (a separate crate) can
construct instances to call split_core on; not part of the
stable Python-facing API surface.