pub struct PyLogisticRegression { /* private fields */ }Expand description
Logistic Regression (aka logit, MaxEnt) classifier.
In the multiclass case, the training algorithm uses the one-vs-rest (OvR) scheme if the ‘multi_class’ option is set to ‘ovr’, and uses the cross-entropy loss if the ‘multi_class’ option is set to ‘multinomial’.
This class implements regularized logistic regression using various solvers. Note that regularization is applied by default.
Parameters
penalty- One of “l1”, “l2”, “elasticnet”. Default: “l2”tol- Tolerance for stopping criteria. Default: 1e-4c- Inverse of regularization strength. Default: 1.0fit_intercept- Whether to add bias term. Default: truesolver- One of “lbfgs”, “newton-cg”, “sag”, “saga”. Default: “lbfgs”max_iter- Maximum iterations. Default: 100multi_class- One of “auto”, “ovr”, “multinomial”. Default: “auto”random_state- Random seed for reproducibilityl1_ratio- Elastic-Net mixing parameter (0 to 1)
References