PyMinMaxScaler

Struct PyMinMaxScaler 

pub struct PyMinMaxScaler { /* private fields */ }
Transform features by scaling each feature to a given range.

This estimator scales and translates each feature individually such that it is in the given range on the training set, e.g. between zero and one.

The transformation is given by:

X_std = (X - X.min(axis=0)) / (X.max(axis=0) - X.min(axis=0))
X_scaled = X_std * (max - min) + min

where min, max = feature_range.

This transformation is often used as an alternative to zero mean, unit variance scaling.

Parameters

feature_range : tuple (min, max), default=(0, 1) Desired range of transformed data.

copy : bool, default=True Set to False to perform inplace row normalization and avoid a copy (if the input is already a numpy array).

clip : bool, default=False Set to True to clip transformed values of held-out data to provided feature range.

Attributes

min_ : ndarray of shape (n_features,) Per feature adjustment for minimum. Equivalent to min - X.min(axis=0) * self.scale_

scale_ : ndarray of shape (n_features,) Per feature relative scaling of the data. Equivalent to (max - min) / (X.max(axis=0) - X.min(axis=0))

data_min_ : ndarray of shape (n_features,) Per feature minimum seen in the data

data_max_ : ndarray of shape (n_features,) Per feature maximum seen in the data

data_range_ : ndarray of shape (n_features,) Per feature range (data_max_ - data_min_) seen in the data

n_features_in_ : int Number of features seen during :term:fit.

n_samples_seen_ : int The number of samples processed by the estimator. It will be reset on new calls to fit, but increments across partial_fit calls.

Examples

from sklears_python import MinMaxScaler import numpy as np data = [[-1, 2], [-0.5, 6], [0, 10], [1, 18]] scaler = MinMaxScaler() scaler.fit(data) MinMaxScaler() print(scaler.data_max_) [ 1. 18.] print(scaler.transform(data)) [[0. 0. ] [0.25 0.25] [0.5 0.5 ] [1. 1. ]] print(scaler.transform([[2, 2]])) [[1.5 0. ]]