PyStandardScaler

Struct PyStandardScaler 

pub struct PyStandardScaler { /* private fields */ }
Standardize features by removing the mean and scaling to unit variance.

The standard score of a sample x is calculated as:

z = (x - u) / s

where u is the mean of the training samples or zero if with_mean=False, and s is the standard deviation of the training samples or one if with_std=False.

Centering and scaling happen independently on each feature by computing the relevant statistics on the samples in the training set. Mean and standard deviation are then stored to be used on later data using :meth:transform.

Standardization of a dataset is a common requirement for many machine learning estimators: they might behave badly if the individual features do not more or less look like standard normally distributed data (e.g. Gaussian with 0 mean and unit variance).

Parameters

copy : bool, default=True If False, try to avoid a copy and do inplace scaling instead. This is not guaranteed to always work inplace; e.g. if the data is not a NumPy array or scipy.sparse CSR matrix, a copy may still be returned.

with_mean : bool, default=True If True, center the data before scaling. This does not work (and will raise an exception) when attempted on sparse matrices, because centering them entails building a dense matrix which in common use cases is likely to be too large to fit in memory.

with_std : bool, default=True If True, scale the data to unit variance (or equivalently, unit standard deviation).

Attributes

scale_ : ndarray of shape (n_features,) or None Per feature relative scaling of the data to achieve zero mean and unit variance. Generally this is calculated using np.sqrt(var_). If a variance is zero, we can’t achieve unit variance, and the data is left as-is, giving a scaling factor of 1. scale_ is equal to None when with_std=False.

mean_ : ndarray of shape (n_features,) or None The mean value for each feature in the training set. Equal to None when with_mean=False.

var_ : ndarray of shape (n_features,) or None The variance for each feature in the training set. Used to compute scale_. Equal to None when with_std=False.

n_features_in_ : int Number of features seen during :term:fit.

n_samples_seen_ : int The number of samples processed by the estimator. It will be reset on new calls to fit, but increments across partial_fit calls.

Examples

from sklears_python import StandardScaler import numpy as np data = [[0, 0], [0, 0], [1, 1], [1, 1]] scaler = StandardScaler() scaler.fit(data) StandardScaler() print(scaler.mean_) [0.5 0.5] print(scaler.transform(data)) [[-1. -1.] [-1. -1.] [ 1. 1.] [ 1. 1.]] print(scaler.transform([[2, 2]])) [[3. 3.]]